==> zjkj-wzxt-impl-3.0.0-20240801.022331-13-sources.jar: com/ejianc/wzxt/order/bean/OrderDetailEntity.java <==
package com.ejianc.wzxt.order.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 材料订单子表
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_order_detail")
public class OrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="contract_detail_id")
    private Long contractDetailId; // 合同明细ID
    @TableField(value="construction")
    private String construction; // 施工部位
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="plan_nums_sum")
    private BigDecimal planNumsSum; // 计划数量
    @TableField(value="receive_nums_sum")
    private BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="order_num_sum")
    private BigDecimal orderNumSum; // 订单数量
    @TableField(value="surplus_nums_sum")
    private BigDecimal surplusNumsSum; // 计划剩余数量
    @TableField(value="deliver_nums_sum")
    private BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_automatic_weigh")
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）
    @TableField(value="old_detail_automatic_weigh")
    private Integer oldDetailAutomaticWeigh; // 带入的自动称重设置（0：自动称重，1非自动称重）

    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public Integer getOldDetailAutomaticWeigh() {
        return oldDetailAutomaticWeigh;
    }

    public void setOldDetailAutomaticWeigh(Integer oldDetailAutomaticWeigh) {
        this.oldDetailAutomaticWeigh = oldDetailAutomaticWeigh;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public BigDecimal getOrderNumSum() {
        return orderNumSum;
    }

    public void setOrderNumSum(BigDecimal orderNumSum) {
        this.orderNumSum = orderNumSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
}

==> zjkj-wzxt-impl-3.0.0-20240814.071805-76-sources.jar: com/ejianc/wzxt/order/bean/OrderDetailEntity.java <==
package com.ejianc.wzxt.order.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 材料订单子表
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_order_detail")
public class OrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID  materialMonthPlanId
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID  id
    @TableField(value="contract_detail_id")
    private Long contractDetailId; // 合同明细ID
    @TableField(value="construction")
    private String construction; // 施工部位
    @TableField(value="material_id")
    private Long materialId; // 物资主键  materialId
    @TableField(value="material_name")
    private String materialName; // 物资名称  materialName
    @TableField(value="material_code")
    private String materialCode; // 物资编码  materialCode
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别  materialCategoryId
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称  materialCategoryName
    @TableField(value="unit")
    private String unit; // 单位  unit
    @TableField(value="unit_id")
    private Long unitId; // 单位id  unitId
    @TableField(value="spec")
    private String spec; // 规格型号  spec
    @TableField(value="plan_nums_sum")
    private BigDecimal planNumsSum; // 计划数量  planMonthNum
    @TableField(value="receive_nums_sum")
    private BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="order_num_sum")
    private BigDecimal orderNumSum; // 订单数量
    @TableField(value="surplus_nums_sum")
    private BigDecimal surplusNumsSum; // 计划剩余数量
    @TableField(value="deliver_nums_sum")
    private BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_automatic_weigh")
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）
    @TableField(value="old_detail_automatic_weigh")
    private Integer oldDetailAutomaticWeigh; // 带入的自动称重设置（0：自动称重，1非自动称重）

    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public Integer getOldDetailAutomaticWeigh() {
        return oldDetailAutomaticWeigh;
    }

    public void setOldDetailAutomaticWeigh(Integer oldDetailAutomaticWeigh) {
        this.oldDetailAutomaticWeigh = oldDetailAutomaticWeigh;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public BigDecimal getOrderNumSum() {
        return orderNumSum;
    }

    public void setOrderNumSum(BigDecimal orderNumSum) {
        this.orderNumSum = orderNumSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
}
